Form unit test

# Form Widget Unit Test

The form widget takes data in a form and serializes/deserializes it, so it can be submitted as a JSON string of nested objects.

Currently only widgets are supported, not raw elements.

Just HTML text

Description | Name | Form node/widget
--- | --- | ---
DateTextBox inside contentpane | foo.bar.baz.quux |
DateTextBox 2 | available.from |
DateTextBox 3 | available.to |
ComboBox | plop.combo |
CheckBox widget | cb | 1 2 3 4
Radio widget | r | 1 2 3 4
Multi-select | ms1 |
Select | s1 |
Hidden input | h1 |
Auto-sizing textarea | t1 | line 1 line 2
Fixed size textarea | st1 | simple line 1 simple line 2
Editor widget | richtext | <h1>original</h1><p>This is the default content</p>
File upload | filename |
Required Widget | requiredWidget |
Disabled Widget | disabledWidget |
Disabled Required Widget | disabledRequiredWidget |
Read-only Widget | readOnlyWidget |
Duplicate named TextBox 1 | duplicate |
Duplicate named TextBox 2 | duplicate |
Duplicate named TextBox 3 | duplicate |